==> pdfhandoutcrop-0.4.0-py3-none-any.whl: pdfhandoutcrop/language/pdfhandoutcrop_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>PdfHandoutCrop</source>
        <translation>PdfHandoutCrop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Auto detect</source>
        <translation>自動偵測(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Pages per sheet:</source>
        <translation>每張紙的頁數：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Zoom &amp;in</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Zoom &amp;out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Click to set</source>
        <translation>按一下來設定</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Position:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="287"/>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>&amp;Open</source>
        <translation>開啟(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="316"/>
        <source>&amp;Convert</source>
        <translation>轉換(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>About &amp;Qt</source>
        <translation>關於 &amp;Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="45"/>
        <source>PDF documents (*.pdf)</source>
        <translation>PDF 文件 (*.pdf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="40"/>
        <source>{0} - PdfHandoutCrop</source>
        <translation>{0} - PdfHandoutCrop</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="78"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="96"/>
        <source>Loading...</source>
        <translation>載入中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="297"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="100"/>
        <source>Cannot open input file</source>
        <translation>無法開啟輸入檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="250"/>
        <source>Found {0} pages</source>
        <translation>找到 {0} 頁</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="285"/>
        <source>Please click the upper left point of page {0}</source>
        <translation>請按一下第 {0} 頁的左上角</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="291"/>
        <source>Please click the upper left point of any page</source>
        <translation>請按一下任何一頁的左上角</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="297"/>
        <source>Height should be set first</source>
        <translation>應該要先設定高度</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="316"/>
        <source>Please click the lower right point of the page you clicked</source>
        <translation>請按一下你剛剛按的那一頁的右下角</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>&amp;Previous</source>
        <comment>previous page</comment>
        <translation>上一頁(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>&amp;Next</source>
        <comment>next page</comment>
        <translation>下一頁(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="87"/>
        <source>Page {0}</source>
        <translation>第 {0} 頁</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="180"/>
        <source>Finished</source>
        <translation>已完成</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="180"/>
        <source>Convert finished</source>
        <translation>轉換已完成</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>x:</source>
        <comment>x coordinate</comment>
        <translation>x:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>y:</source>
        <comment>y coordinate</comment>
        <translation>y:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>&amp;Reload</source>
        <translation>重新載入(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="78"/>
        <source>&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
Author: Hsiu-Ming Chang&lt;br&gt;
e-mail: cges30901@gmail.com&lt;br&gt;
License: GPL v3</source>
        <translation>&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
作者：張修銘&lt;br&gt;
電子郵件：cges30901@gmail.com&lt;br&gt;
授權：GPL v3</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="187"/>
        <source>Page can not be found</source>
        <translation>無法找到頁面</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="187"/>
        <source>Page can not be found. Auto detect only works if pages have border.</source>
        <translation>無法找到頁面。自動偵測只有在頁面有框線時才能運作。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Width and Height:</source>
        <translation>寬和高：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>&amp;Website</source>
        <translation>網站(&amp;W)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>&amp;Donate</source>
        <translation>捐款(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>&amp;Project page</source>
        <translation>專案頁面(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>&amp;Blog</source>
        <translation>部落格(&amp;B)</translation>
    </message>
</context>
<context>
    <name>SetPagesDialog</name>
    <message>
        <location filename="../setpagesdialog.ui" line="20"/>
        <source>Only one page is detected. Please select layout</source>
        <translation>只偵測到一頁。請選擇版面配置</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="29"/>
        <source>Columns:</source>
        <translation>欄：</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="60"/>
        <source>Rows:</source>
        <translation>列：</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="117"/>
        <source>Ok</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="14"/>
        <source>Select layout</source>
        <translation>選擇版面配置</translation>
    </message>
</context>
</TS>

==> pdfhandoutcrop-0.6.0-py3-none-any.whl: pdfhandoutcrop/language/pdfhandoutcrop_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>PdfHandoutCrop</source>
        <translation>PdfHandoutCrop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Auto detect</source>
        <translation>自動偵測(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Pages per sheet:</source>
        <translation>每張紙的頁數：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Zoom &amp;in</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Zoom &amp;out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Click to set</source>
        <translation>按一下來設定</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Position:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="287"/>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>&amp;Open</source>
        <translation>開啟(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>About &amp;Qt</source>
        <translation>關於 &amp;Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="52"/>
        <source>PDF documents (*.pdf)</source>
        <translation>PDF 文件 (*.pdf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="46"/>
        <source>{0} - PdfHandoutCrop</source>
        <translation>{0} - PdfHandoutCrop</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="81"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="99"/>
        <source>Loading...</source>
        <translation>載入中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="317"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="41"/>
        <source>Cannot open input file</source>
        <translation>無法開啟輸入檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="270"/>
        <source>Found {0} pages</source>
        <translation>找到 {0} 頁</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="305"/>
        <source>Please click the upper left point of page {0}</source>
        <translation>請按一下第 {0} 頁的左上角</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="311"/>
        <source>Please click the upper left point of any page</source>
        <translation>請按一下任何一頁的左上角</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="317"/>
        <source>Height should be set first</source>
        <translation>應該要先設定高度</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="336"/>
        <source>Please click the lower right point of the page you clicked</source>
        <translation>請按一下你剛剛按的那一頁的右下角</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>&amp;Previous</source>
        <comment>previous page</comment>
        <translation>上一頁(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>&amp;Next</source>
        <comment>next page</comment>
        <translation>下一頁(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="90"/>
        <source>Page {0}</source>
        <translation>第 {0} 頁</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="179"/>
        <source>Finished</source>
        <translation>已完成</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>x:</source>
        <comment>x coordinate</comment>
        <translation>x:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>y:</source>
        <comment>y coordinate</comment>
        <translation>y:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>&amp;Reload</source>
        <translation>重新載入(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="81"/>
        <source>&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
Author: Hsiu-Ming Chang&lt;br&gt;
e-mail: cges30901@gmail.com&lt;br&gt;
License: GPL v3</source>
        <translation>&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
作者：張修銘&lt;br&gt;
電子郵件：cges30901@gmail.com&lt;br&gt;
授權：GPL v3</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="186"/>
        <source>Page can not be found</source>
        <translation>無法找到頁面</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="186"/>
        <source>Page can not be found. Auto detect only works if pages have border.</source>
        <translation>無法找到頁面。自動偵測只有在頁面有框線時才能運作。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Width and Height:</source>
        <translation>寬和高：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>&amp;Website</source>
        <translation>網站(&amp;W)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>&amp;Donate</source>
        <translation>捐款(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>&amp;Project page</source>
        <translation>專案頁面(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>&amp;Blog</source>
        <translation>部落格(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="316"/>
        <source>&amp;Save</source>
        <translation>儲存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="41"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="179"/>
        <source>Cropped PDF saved</source>
        <translation>裁切的 PDF 已儲存</translation>
    </message>
</context>
<context>
    <name>SetLayoutDialog</name>
    <message>
        <location filename="../setlayoutdialog.ui" line="14"/>
        <source>Select layout</source>
        <translation>選擇版面配置</translation>
    </message>
    <message>
        <location filename="../setlayoutdialog.ui" line="20"/>
        <source>Only one page is detected. Please select layout</source>
        <translation>只偵測到一頁。請選擇版面配置</translation>
    </message>
    <message>
        <location filename="../setlayoutdialog.ui" line="140"/>
        <source>Ok</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../setlayoutdialog.py" line="9"/>
        <source>left to right, then down</source>
        <translation>由左至右，再向下</translation>
    </message>
    <message>
        <location filename="../setlayoutdialog.py" line="10"/>
        <source>right to left, then down</source>
        <translation>由右至左，再向下</translation>
    </message>
    <message>
        <location filename="../setlayoutdialog.py" line="11"/>
        <source>top to bottom, then right</source>
        <translation>由上至下，再向右</translation>
    </message>
    <message>
        <location filename="../setlayoutdialog.py" line="12"/>
        <source>top to bottom, then left</source>
        <translation>由上至下，再向左</translation>
    </message>
    <message>
        <location filename="../setlayoutdialog.ui" line="29"/>
        <source>&amp;Columns:</source>
        <translation>欄(&amp;C)：</translation>
    </message>
    <message>
        <location filename="../setlayoutdialog.ui" line="63"/>
        <source>&amp;Rows:</source>
        <translation>列(&amp;R)：</translation>
    </message>
    <message>
        <location filename="../setlayoutdialog.ui" line="97"/>
        <source>&amp;Order:</source>
        <translation>順序(&amp;O)：</translation>
    </message>
</context>
</TS>
